@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2013 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,7 +15,10 @@
  */
 package org.easymock.internal;
 
-public interface IMocksBehavior extends ILegacyMatcherMethods {
+/**
+ * @author OFFIS, Tammo Freese
+ */
+public interface IMocksBehavior {
 
     // record
     void addExpected(ExpectedInvocation expected, Result result, Range count);
@@ -25,12 +28,12 @@ public interface IMocksBehavior extends ILegacyMatcherMethods {
     void checkOrder(boolean value);
 
     void makeThreadSafe(boolean isThreadSafe);
-    
+
     void shouldBeUsedInOneThread(boolean shouldBeUsedInOneThread);
-    
+
     // replay
-    Result addActual(Invocation invocation);    
-    
+    Result addActual(Invocation invocation);
+
     boolean isThreadSafe();
 
     void checkThreadSafety();
