@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2013 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,22 +19,24 @@ import java.io.Serializable;
 
 import org.easymock.IArgumentMatcher;
 
+/**
+ * @author OFFIS, Tammo Freese
+ */
 public class Contains implements IArgumentMatcher, Serializable {
 
     private static final long serialVersionUID = -6785245714002503134L;
 
     private final String substring;
 
-    public Contains(String substring) {
+    public Contains(final String substring) {
         this.substring = substring;
     }
 
-    public boolean matches(Object actual) {
-        return (actual instanceof String)
-                && ((String) actual).indexOf(substring) >= 0;
+    public boolean matches(final Object actual) {
+        return (actual instanceof String) && ((String) actual).indexOf(substring) >= 0;
     }
 
-    public void appendTo(StringBuffer buffer) {
+    public void appendTo(final StringBuffer buffer) {
         buffer.append("contains(\"" + substring + "\")");
     }
 }
