@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2013 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -20,21 +20,24 @@ import java.io.Serializable;
 import org.easymock.IArgumentMatcher;
 import org.easymock.internal.ArgumentToString;
 
+/**
+ * @author OFFIS, Tammo Freese
+ */
 public class Same implements IArgumentMatcher, Serializable {
 
     private static final long serialVersionUID = 1094930851962278376L;
-    
+
     private final Object expected;
 
-    public Same(Object expected) {
+    public Same(final Object expected) {
         this.expected = expected;
     }
 
-    public boolean matches(Object actual) {
+    public boolean matches(final Object actual) {
         return expected == actual;
     }
 
-    public void appendTo(StringBuffer buffer) {
+    public void appendTo(final StringBuffer buffer) {
         buffer.append("same(");
         ArgumentToString.appendArgument(expected, buffer);
         buffer.append(")");
