@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2013 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -30,6 +30,9 @@ import org.easymock.tests.IMethods;
 import org.junit.Before;
 import org.junit.Test;
 
+/**
+ * @author OFFIS, Tammo Freese
+ */
 public class UsageConstraintsTest {
     private IMethods mock;
 
@@ -44,20 +47,26 @@ public class UsageConstraintsTest {
         try {
             mock.simpleMethodWithArgument(not("jkl"));
             fail();
-        } catch (IllegalStateException e) {
+        } catch (final IllegalStateException e) {
             assertEquals("no matchers found.", e.getMessage());
         }
         try {
             mock.simpleMethodWithArgument(or(eq("jkl"), "asd"));
             fail();
-        } catch (IllegalStateException e) {
+        } catch (final IllegalStateException e) {
             assertEquals("2 matchers expected, 1 recorded.", e.getMessage());
         }
         try {
             mock.threeArgumentMethod(1, "asd", eq("asd"));
             fail();
-        } catch (IllegalStateException e) {
-            assertEquals("3 matchers expected, 1 recorded.", e.getMessage());
+        } catch (final IllegalStateException e) {
+            assertEquals(
+                    "3 matchers expected, 1 recorded.\n"
+                            + "This exception usually occurs when matchers are mixed with raw values when recording a method:\n"
+                            + "\tfoo(5, eq(6));\t// wrong\n"
+                            + "You need to use no matcher at all or a matcher for every single param:\n"
+                            + "\tfoo(eq(5), eq(6));\t// right\n" + "\tfoo(5, 6);\t// also right",
+                    e.getMessage());
         }
 
     }
@@ -80,21 +89,19 @@ public class UsageConstraintsTest {
         try {
             new Equals(null).hashCode();
             fail();
-        } catch (UnsupportedOperationException expected) {
+        } catch (final UnsupportedOperationException expected) {
         }
     }
 
     @Test
     public void constraints() {
-        expect(
-                mock.threeArgumentMethod(and(geq(7), leq(10)),
-                        isA(String.class), contains("123"))).andReturn("456")
-                .atLeastOnce();
+        expect(mock.threeArgumentMethod(and(geq(7), leq(10)), isA(String.class), contains("123"))).andReturn(
+                "456").atLeastOnce();
         replay(mock);
         boolean failed = false;
         try {
             mock.threeArgumentMethod(11, "", "01234");
-        } catch (AssertionError expected) {
+        } catch (final AssertionError expected) {
             failed = true;
         }
         if (!failed) {
@@ -103,7 +110,7 @@ public class UsageConstraintsTest {
         failed = false;
         try {
             mock.threeArgumentMethod(8, new Object(), "01234");
-        } catch (AssertionError expected) {
+        } catch (final AssertionError expected) {
             failed = true;
         }
         if (!failed) {
@@ -112,7 +119,7 @@ public class UsageConstraintsTest {
         failed = false;
         try {
             mock.threeArgumentMethod(8, "", "no match");
-        } catch (AssertionError expected) {
+        } catch (final AssertionError expected) {
             failed = true;
         }
         if (!failed) {
@@ -129,12 +136,11 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(and(eq('a'), eq('a')))).andReturn("2");
         expect(mock.oneArg(and(eq((double) 1), eq((double) 1)))).andReturn("3");
         expect(mock.oneArg(and(eq((float) 1), eq((float) 1)))).andReturn("4");
-        expect(mock.oneArg(and(eq((int) 1), eq((int) 1)))).andReturn("5");
+        expect(mock.oneArg(and(eq(1), eq(1)))).andReturn("5");
         expect(mock.oneArg(and(eq((long) 1), eq((long) 1)))).andReturn("6");
         expect(mock.oneArg(and(eq((short) 1), eq((short) 1)))).andReturn("7");
         expect(mock.oneArg(and(contains("a"), contains("d")))).andReturn("8");
-        expect(mock.oneArg(and(isA(Class.class), eq(Object.class)))).andReturn(
-                "9");
+        expect(mock.oneArg(and(isA(Class.class), eq(Object.class)))).andReturn("9");
         replay(mock);
         assertEquals("9", mock.oneArg(Object.class));
         assertEquals("0", mock.oneArg(false));
@@ -144,7 +150,7 @@ public class UsageConstraintsTest {
         assertEquals("7", mock.oneArg((short) 1));
         assertEquals("8", mock.oneArg("abcde"));
         assertEquals("4", mock.oneArg((float) 1));
-        assertEquals("5", mock.oneArg((int) 1));
+        assertEquals("5", mock.oneArg(1));
         assertEquals("6", mock.oneArg((long) 1));
         verify(mock);
     }
@@ -156,12 +162,11 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(or(eq((char) 1), eq((char) 2)))).andReturn("2");
         expect(mock.oneArg(or(eq((double) 1), eq((double) 2)))).andReturn("3");
         expect(mock.oneArg(or(eq((float) 1), eq((float) 2)))).andReturn("4");
-        expect(mock.oneArg(or(eq((int) 1), eq((int) 2)))).andReturn("5");
+        expect(mock.oneArg(or(eq(1), eq(2)))).andReturn("5");
         expect(mock.oneArg(or(eq((long) 1), eq((long) 2)))).andReturn("6");
         expect(mock.oneArg(or(eq((short) 1), eq((short) 2)))).andReturn("7");
         expect(mock.oneArg(or(eq("asd"), eq("jkl")))).andReturn("8");
-        expect(mock.oneArg(or(eq(this.getClass()), eq(Object.class))))
-                .andReturn("9");
+        expect(mock.oneArg(or(eq(this.getClass()), eq(Object.class)))).andReturn("9");
         replay(mock);
         assertEquals("9", mock.oneArg(Object.class));
         assertEquals("0", mock.oneArg(true));
@@ -171,7 +176,7 @@ public class UsageConstraintsTest {
         assertEquals("7", mock.oneArg((short) 1));
         assertEquals("8", mock.oneArg("jkl"));
         assertEquals("4", mock.oneArg((float) 1));
-        assertEquals("5", mock.oneArg((int) 2));
+        assertEquals("5", mock.oneArg(2));
         assertEquals("6", mock.oneArg((long) 1));
         verify(mock);
     }
@@ -183,7 +188,7 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(not(eq('a')))).andReturn("2");
         expect(mock.oneArg(not(eq((double) 1)))).andReturn("3");
         expect(mock.oneArg(not(eq((float) 1)))).andReturn("4");
-        expect(mock.oneArg(not(eq((int) 1)))).andReturn("5");
+        expect(mock.oneArg(not(eq(1)))).andReturn("5");
         expect(mock.oneArg(not(eq((long) 1)))).andReturn("6");
         expect(mock.oneArg(not(eq((short) 1)))).andReturn("7");
         expect(mock.oneArg(not(contains("a")))).andReturn("8");
@@ -197,7 +202,7 @@ public class UsageConstraintsTest {
         assertEquals("7", mock.oneArg((short) 2));
         assertEquals("8", mock.oneArg("bcde"));
         assertEquals("4", mock.oneArg((float) 2));
-        assertEquals("5", mock.oneArg((int) 2));
+        assertEquals("5", mock.oneArg(2));
         assertEquals("6", mock.oneArg((long) 2));
         verify(mock);
     }
@@ -207,7 +212,7 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(leq((byte) 1))).andReturn("1");
         expect(mock.oneArg(leq((double) 1))).andReturn("3");
         expect(mock.oneArg(leq((float) 1))).andReturn("4");
-        expect(mock.oneArg(leq((int) 1))).andReturn("5");
+        expect(mock.oneArg(leq(1))).andReturn("5");
         expect(mock.oneArg(leq((long) 1))).andReturn("6");
         expect(mock.oneArg(leq((short) 1))).andReturn("7");
         expect(mock.oneArg(leq(new BigDecimal("1")))).andReturn("8");
@@ -216,7 +221,7 @@ public class UsageConstraintsTest {
         assertEquals("3", mock.oneArg((double) 1));
         assertEquals("7", mock.oneArg((short) 0));
         assertEquals("4", mock.oneArg((float) -5));
-        assertEquals("5", mock.oneArg((int) -2));
+        assertEquals("5", mock.oneArg(-2));
         assertEquals("6", mock.oneArg((long) -3));
         assertEquals("8", mock.oneArg(new BigDecimal("0.5")));
         verify(mock);
@@ -227,7 +232,7 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(lt((byte) 1))).andReturn("1");
         expect(mock.oneArg(lt((double) 1))).andReturn("3");
         expect(mock.oneArg(lt((float) 1))).andReturn("4");
-        expect(mock.oneArg(lt((int) 1))).andReturn("5");
+        expect(mock.oneArg(lt(1))).andReturn("5");
         expect(mock.oneArg(lt((long) 1))).andReturn("6");
         expect(mock.oneArg(lt((short) 1))).andReturn("7");
         expect(mock.oneArg(lt(new BigDecimal("1")))).andReturn("8");
@@ -236,7 +241,7 @@ public class UsageConstraintsTest {
         assertEquals("3", mock.oneArg((double) 0));
         assertEquals("7", mock.oneArg((short) 0));
         assertEquals("4", mock.oneArg((float) -4));
-        assertEquals("5", mock.oneArg((int) -34));
+        assertEquals("5", mock.oneArg(-34));
         assertEquals("6", mock.oneArg((long) -6));
         assertEquals("8", mock.oneArg(new BigDecimal("0.5")));
         verify(mock);
@@ -247,7 +252,7 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(geq((byte) 1))).andReturn("1");
         expect(mock.oneArg(geq((double) 1))).andReturn("3");
         expect(mock.oneArg(geq((float) 1))).andReturn("4");
-        expect(mock.oneArg(geq((int) 1))).andReturn("5");
+        expect(mock.oneArg(geq(1))).andReturn("5");
         expect(mock.oneArg(geq((long) 1))).andReturn("6");
         expect(mock.oneArg(geq((short) 1))).andReturn("7");
         expect(mock.oneArg(geq(new BigDecimal("1")))).andReturn("8");
@@ -256,7 +261,7 @@ public class UsageConstraintsTest {
         assertEquals("3", mock.oneArg((double) 1));
         assertEquals("7", mock.oneArg((short) 2));
         assertEquals("4", mock.oneArg((float) 3));
-        assertEquals("5", mock.oneArg((int) 4));
+        assertEquals("5", mock.oneArg(4));
         assertEquals("6", mock.oneArg((long) 5));
         assertEquals("8", mock.oneArg(new BigDecimal("1.5")));
         verify(mock);
@@ -267,7 +272,7 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(gt((byte) 1))).andReturn("1");
         expect(mock.oneArg(gt((double) 1))).andReturn("3");
         expect(mock.oneArg(gt((float) 1))).andReturn("4");
-        expect(mock.oneArg(gt((int) 1))).andReturn("5");
+        expect(mock.oneArg(gt(1))).andReturn("5");
         expect(mock.oneArg(gt((long) 1))).andReturn("6");
         expect(mock.oneArg(gt((short) 1))).andReturn("7");
         expect(mock.oneArg(gt(new BigDecimal("1")))).andReturn("8");
@@ -276,7 +281,7 @@ public class UsageConstraintsTest {
         assertEquals("3", mock.oneArg((double) 2));
         assertEquals("7", mock.oneArg((short) 2));
         assertEquals("4", mock.oneArg((float) 3));
-        assertEquals("5", mock.oneArg((int) 2));
+        assertEquals("5", mock.oneArg(2));
         assertEquals("6", mock.oneArg((long) 5));
         assertEquals("8", mock.oneArg(new BigDecimal("1.5")));
         verify(mock);
@@ -291,9 +296,9 @@ public class UsageConstraintsTest {
     }
 
     public static class A {
-        private int value;
+        private final int value;
 
-        public A(int value) {
+        public A(final int value) {
             this.value = value;
         }
 
@@ -305,13 +310,13 @@ public class UsageConstraintsTest {
     @Test
     public void compareWithComparator() {
         // Undertype just to make sure the generic typing works
-        Comparator<Object> comparator = new Comparator<Object>() {
-            private int compare(A a1, A a2) {
+        final Comparator<Object> comparator = new Comparator<Object>() {
+            private int compare(final A a1, final A a2) {
                 return a1.getValue() - a2.getValue();
             }
 
-            public int compare(Object o1, Object o2) {
-                return compare((A)o1, (A)o2);
+            public int compare(final Object o1, final Object o2) {
+                return compare((A) o1, (A) o2);
             }
         };
 
@@ -322,47 +327,40 @@ public class UsageConstraintsTest {
 
         // Now test EasyMock.cmp
         checkOrder(mock, true);
-        
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.EQUAL))).andReturn("0");
-        
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.GREATER))).andReturn("1");
-        
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.GREATER_OR_EQUAL))).andReturn("2");
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.GREATER_OR_EQUAL))).andReturn("2");
-        
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.LESS_OR_EQUAL))).andReturn("3");
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.LESS_OR_EQUAL))).andReturn("3");
-        
-        expect(mock.oneArg(cmp(new A(5), comparator, 
-                LogicalOperator.LESS_THAN))).andReturn("4");
-                
+
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.EQUAL))).andReturn("0");
+
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.GREATER))).andReturn("1");
+
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.GREATER_OR_EQUAL))).andReturn("2");
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.GREATER_OR_EQUAL))).andReturn("2");
+
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.LESS_OR_EQUAL))).andReturn("3");
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.LESS_OR_EQUAL))).andReturn("3");
+
+        expect(mock.oneArg(cmp(new A(5), comparator, LogicalOperator.LESS_THAN))).andReturn("4");
+
         replay(mock);
-        
+
         checkItFails(null); // null is not comparable so always return false
         try {
             mock.oneArg("");
             fail();
-        }
-        catch(AssertionError e) {} // different type isn't either
-        
+        } catch (final AssertionError e) {
+        } // different type isn't either
+
         checkItFails(new A(4));
         checkItFails(new A(6));
         assertEquals("0", mock.oneArg(new A(5)));
 
         checkItFails(new A(4));
-        checkItFails(new A(5));        
+        checkItFails(new A(5));
         assertEquals("1", mock.oneArg(new A(6)));
-        
+
         checkItFails(new A(4));
         assertEquals("2", mock.oneArg(new A(6)));
         assertEquals("2", mock.oneArg(new A(5)));
-        
+
         checkItFails(new A(6));
         assertEquals("3", mock.oneArg(new A(4)));
         assertEquals("3", mock.oneArg(new A(5)));
@@ -370,16 +368,16 @@ public class UsageConstraintsTest {
         checkItFails(new A(5));
         checkItFails(new A(6));
         assertEquals("4", mock.oneArg(new A(4)));
-        
+
         verify(mock);
     }
 
-    private void checkItFails(A a) {
+    private void checkItFails(final A a) {
         try {
             mock.oneArg(a);
             fail();
+        } catch (final AssertionError e) {
         }
-        catch(AssertionError e) {}
     }
 
     @Test
@@ -393,7 +391,9 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(anyLong())).andReturn("6");
         expect(mock.oneArg(anyShort())).andReturn("7");
         expect(mock.oneArg((String) anyObject())).andReturn("8");
-        expect(mock.oneArg((List<String>) EasyMock.<List<String>>anyObject())).andReturn("9"); // make sure there's no warning on the cast
+        expect(mock.oneArg(anyObject(String.class))).andReturn("9");
+        expect(mock.oneArg(EasyMock.<List<String>> anyObject())).andReturn("9"); // make sure there's no warning on the cast
+        expect(mock.oneArg(anyString())).andReturn("10");
         replay(mock);
         assertEquals("9", mock.oneArg(Collections.emptyList()));
         assertEquals("0", mock.oneArg(true));
@@ -403,10 +403,12 @@ public class UsageConstraintsTest {
         assertEquals("7", mock.oneArg((short) 1));
         assertEquals("8", mock.oneArg("Test"));
         assertEquals("4", mock.oneArg((float) 1));
-        assertEquals("5", mock.oneArg((int) 1));
+        assertEquals("5", mock.oneArg(1));
         assertEquals("6", mock.oneArg((long) 1));
+        assertEquals("9", mock.oneArg("Other Test"));
+        assertEquals("10", mock.oneArg(""));
         verify(mock);
-    }    
+    }
 
     @Test
     public void arrayEquals() {
@@ -514,30 +516,30 @@ public class UsageConstraintsTest {
 
     @Test
     public void testNull() {
-        expect(mock.threeArgumentMethod(eq(1), isNull(), eq("")))
-                .andReturn("1").atLeastOnce();
-        expect(mock.threeArgumentMethod(eq(1), not(isNull()), eq("")))
-                .andStubReturn("2");
+        expect(mock.threeArgumentMethod(eq(1), isNull(), eq(""))).andReturn("1");
+        expect(mock.threeArgumentMethod(eq(1), isNull(Object.class), eq(""))).andReturn("2");
+        expect(mock.threeArgumentMethod(eq(1), not(isNull()), eq(""))).andStubReturn("3");
 
         replay(mock);
 
         assertEquals("1", mock.threeArgumentMethod(1, null, ""));
-        assertEquals("2", mock.threeArgumentMethod(1, new Object(), ""));
+        assertEquals("2", mock.threeArgumentMethod(1, null, ""));
+        assertEquals("3", mock.threeArgumentMethod(1, new Object(), ""));
 
         verify(mock);
     }
 
     @Test
     public void testNotNull() {
-        expect(mock.threeArgumentMethod(eq(1), notNull(), eq(""))).andReturn(
-                "1").atLeastOnce();
-        expect(mock.threeArgumentMethod(eq(1), not(notNull()), eq("")))
-                .andStubReturn("2");
+        expect(mock.threeArgumentMethod(eq(1), notNull(), eq(""))).andReturn("1");
+        expect(mock.threeArgumentMethod(eq(1), notNull(Object.class), eq(""))).andReturn("2");
+        expect(mock.threeArgumentMethod(eq(1), not(notNull()), eq(""))).andStubReturn("3");
 
         replay(mock);
 
         assertEquals("1", mock.threeArgumentMethod(1, new Object(), ""));
-        assertEquals("2", mock.threeArgumentMethod(1, null, ""));
+        assertEquals("2", mock.threeArgumentMethod(1, new Object(), ""));
+        assertEquals("3", mock.threeArgumentMethod(1, null, ""));
 
         verify(mock);
     }
@@ -557,8 +559,7 @@ public class UsageConstraintsTest {
 
     @Test
     public void testMatches() {
-        expect(mock.oneArg(matches("[a-z]+\\d\\d"))).andReturn("1")
-                .atLeastOnce();
+        expect(mock.oneArg(matches("[a-z]+\\d\\d"))).andReturn("1").atLeastOnce();
         expect(mock.oneArg(matches("\\d\\d\\d"))).andStubReturn("2");
 
         replay(mock);
@@ -633,8 +634,8 @@ public class UsageConstraintsTest {
 
     @Test
     public void testSame() {
-        Object one = new String("1243");
-        Object two = new String("1243");
+        final Object one = new String("1243");
+        final Object two = new String("1243");
 
         assertNotSame(one, two);
         assertEquals(one, two);
